#!/usr/bin/env python

# alpha-layers-to-svg.py
# This plug-in will try to loop through all layers named something like a.png,b.png...ect.
# Alpha-to-selection each layer, convert it to path then export as a.svg,b.svg...ect. to the selected directory.
# Requested by Krikor in https://gimplearn.net/viewtopic.php?f=9&t=2942

# Created by Tin Tran http://gimplearn.net
# License: GPLv3
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY# without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# To view a copy of the GNU General Public License
# visit: http://www.gnu.org/licenses/gpl.html
#
#
# ------------
#| Change Log |
# ------------
# Rel 1: Initial release.
# Rel 2: Only try to export to svg if there is something selected.
# Rel 3: If error exporting to filename, export it as error_#.svg
# Rel 3.1: (25/02/2023) MrQ: add Remove the extension in the layer name if exist, name the svg and paths the same as the layer names, add optin:"Path visible?", keep path exported as vectors(svg), remowe selection.

import random
import math
from gimpfu import *
#from array import array
import sys
import os
invalidchars = "\/" #on Linux only escape this forward slash as it is to separate directory names.
def python_tt_alpha_layers_to_svg(image, layer, dirname, path_v):
	pdb.gimp_progress_update(0)
	pdb.gimp_progress_set_text("Exporting SVGs...");
	layercount = len(image.layers)
	count = 0
	for lyr in image.layers:

################## add MrQ #############
#  Remove the extension in the layer name if exist

		for layer in image.layers:
			sourcename = layer.name		
			if '.' in sourcename:
				split = sourcename.split(".", 1)
				sourcename = split[0]
				layer.name = sourcename
########################################			
		count += 1
		pdb.gimp_progress_update(float(count)/layercount);
		pdb.gimp_image_select_item(image,CHANNEL_OP_REPLACE,lyr)
		non_empty,x1,y1,x2,y2 = pdb.gimp_selection_bounds(image)
		error = 0
		if non_empty:
			pdb.plug_in_sel2path(image,lyr)
			vectors = pdb.gimp_image_get_active_vectors(image)
			
			if path_v==1:                                    # add MrQ	
				pdb.gimp_item_set_visible(vectors, 1)

			#svgname = layername.replace(".png", ".svg")     # MrQ
			
			pdb.gimp_item_set_name(vectors, lyr.name)        # add MrQ
			svgname = lyr.name + "." + "svg"				 # add MrQ
			if svgname[0] in invalidchars: #if it contains invalid characters
				svgname =svgname   #add escape to it.
			pdb.gimp_progress_set_text("Exporting "+svgname)
			try:
  				pdb.gimp_vectors_export_to_file(image,os.path.join(dirname,svgname),vectors)
			except:
				#if error exporting to file we try exporting it as error_#.svg
				error += 1
				svgname = "error_"+str(error)+".svg"
				pdb.gimp_vectors_export_to_file(image,os.path.join(dirname,svgname),vectors)
                         					
			#remove vectors after we're done so we can start fresh with the next layer
			#pdb.gimp_image_remove_vectors(image,vectors)     # MrQ
			
  	pdb.gimp_selection_none(image)			
		
	
	
register(
	"python_fu_tt_alpha_layers_to_svg",                           
	"Export alpha layers to *.svg and Import as paths. Ver.3.1",
	"Export alpha layers to *.svg",
	"Tin Tran",
	"Tin Tran",
	"April 2021",
	"<Image>/Filters/Path/Alpha-Layers-to-SVG...",             #Menu path
	"RGB*, GRAY*", 
	[
	(PF_DIRNAME, "dirname", "SVG Output Directory:", 0),
	(PF_TOGGLE , 'path_v', "Path visible?", 0,["No","YES"]),
	],
	[],
	python_tt_alpha_layers_to_svg)

main()
